"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useChatConfigurations = exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _services = require("../services");
var _utils = require("../utils");
var _global = require("../global");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultBotConfig = {
  title: 'Bot title',
  botFab: '',
  colors: {
    main: '#254EDB',
    mainText: '#FFFFFF',
    secondary: '#DADCE3',
    secondaryText: '#5A5D68'
  }
};
const ChatConfigurationsContext = /*#__PURE__*/(0, _react.createContext)({
  isChatOpen: false,
  toggleIsChatOpen: () => {},
  setBotConfigs: () => {},
  botConfigs: defaultBotConfig,
  fetchBotAndUpdateConfigs: async () => {}
});
const IsChatOpenProvider = _ref => {
  let {
    children,
    appearance,
    apiUrl
  } = _ref;
  const getBotService = (0, _services.createService)(apiUrl);
  const [isChatOpen, setIsChatOpen] = (0, _react.useState)(false);
  const [configs, setConfigs] = (0, _react.useState)(defaultBotConfig);
  const toggleIsChatOpen = (0, _react.useCallback)(() => {
    setIsChatOpen(oldValue => !oldValue);
  }, [isChatOpen, setIsChatOpen]);
  const setBotConfigs = (0, _react.useCallback)(cfg => setConfigs(cfg), []);
  const fetchBotAndUpdateConfigs = (0, _react.useCallback)(async () => {
    try {
      var _data$channels, _webchatChannel$setti, _webchatChannel$setti2, _webchatChannel$setti3, _webchatChannel$setti4, _webchatChannel$setti5;
      const {
        data
      } = await getBotService.get(_global.Global.botId);
      const [webchatChannel] = data === null || data === void 0 ? void 0 : (_data$channels = data.channels) === null || _data$channels === void 0 ? void 0 : _data$channels.filter(ch => {
        return ch.channelId === 'WebChat';
      });
      const botConfigs = {
        title: data === null || data === void 0 ? void 0 : data.title,
        botFab: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti = webchatChannel.settings) === null || _webchatChannel$setti === void 0 ? void 0 : _webchatChannel$setti.botFab),
        colors: {
          main: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti2 = webchatChannel.settings) === null || _webchatChannel$setti2 === void 0 ? void 0 : _webchatChannel$setti2.mainColor),
          secondary: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti3 = webchatChannel.settings) === null || _webchatChannel$setti3 === void 0 ? void 0 : _webchatChannel$setti3.secondaryColor),
          mainText: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti4 = webchatChannel.settings) === null || _webchatChannel$setti4 === void 0 ? void 0 : _webchatChannel$setti4.mainTextColor),
          secondaryText: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti5 = webchatChannel.settings) === null || _webchatChannel$setti5 === void 0 ? void 0 : _webchatChannel$setti5.secondaryTextColor)
        }
      };
      setBotConfigs({
        ...botConfigs,
        ...appearance,
        colors: {
          ...botConfigs.colors,
          ...(appearance === null || appearance === void 0 ? void 0 : appearance.colors)
        }
      });
    } catch (error) {
      _utils.logger.log(`Error getting bot styles: ${JSON.stringify(error)}`);
      setBotConfigs({
        ...defaultBotConfig,
        ...appearance,
        colors: {
          ...defaultBotConfig.colors,
          ...(appearance === null || appearance === void 0 ? void 0 : appearance.colors)
        }
      });
    }
  }, []);
  const chatConfigurationsState = {
    isChatOpen,
    toggleIsChatOpen,
    setBotConfigs,
    botConfigs: configs,
    fetchBotAndUpdateConfigs
  };
  return /*#__PURE__*/_react.default.createElement(ChatConfigurationsContext.Provider, {
    value: chatConfigurationsState
  }, children);
};
var _default = IsChatOpenProvider;
exports.default = _default;
const useChatConfigurations = () => (0, _react.useContext)(ChatConfigurationsContext);
exports.useChatConfigurations = useChatConfigurations;
//# sourceMappingURL=ChatConfigurations.js.map