"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStorage = exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _Context = require("./Context");
var _types = require("../../types");
var _useEncryptedStorage = require("../../hooks/useEncryptedStorage");
var _useDebounce = require("../../hooks/useDebounce");
var _utils = require("../../utils");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const TWO_SECONDS = 2000;
const StorageContextComponent = _ref => {
  let {
    children
  } = _ref;
  const {
    retrieve,
    store
  } = (0, _useEncryptedStorage.useEncryptedStorage)();
  const [messages, setMessages] = (0, _react.useState)([]);
  const debouncedMessages = (0, _useDebounce.useDebounce)(messages, TWO_SECONDS);
  (0, _react.useEffect)(() => {
    const getStoredData = async () => {
      const storedMessages = await retrieve('messages');
      if (storedMessages) setMessages(JSON.parse(storedMessages));
    };
    getStoredData();
  }, []);
  (0, _react.useEffect)(() => {
    const storeMessages = async () => {
      if (debouncedMessages.length) {
        store('messages', debouncedMessages);
      }
    };
    storeMessages();
  }, [debouncedMessages]);
  const addMessage = newMessage => {
    setMessages(prevState => {
      var _prevState$filter;
      const newMessages = [...((prevState === null || prevState === void 0 ? void 0 : (_prevState$filter = prevState.filter) === null || _prevState$filter === void 0 ? void 0 : _prevState$filter.call(prevState, m => m.type !== _types.MessageTypes.TYPING)) ?? []), {
        ...newMessage,
        hour: (0, _utils.getHourAndMinutes)()
      }];
      return newMessages;
    });
  };
  const resetMessages = () => setMessages([]);
  return /*#__PURE__*/_react.default.createElement(_Context.StorageContextProvider, {
    value: {
      messages,
      addMessage,
      resetMessages
    }
  }, children);
};
var _default = StorageContextComponent;
exports.default = _default;
const useStorage = () => (0, _react.useContext)(_Context.StorageContext);
exports.useStorage = useStorage;
//# sourceMappingURL=Component.js.map