"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEncryptedStorage = void 0;
var _react = require("react");
var _providers = require("../providers");
var _utils = require("../utils");
const useEncryptedStorage = () => {
  const storageRef = (0, _react.useRef)(new _providers.EncryptedStorageProvider());
  const store = async (key, data) => {
    try {
      await storageRef.current.storeData(key, data);
    } catch (error) {
      _utils.logger.log(`Error storing data: ${JSON.stringify(error)}`);
    }
  };
  const retrieve = async key => {
    try {
      const data = await storageRef.current.retrieveData(key);
      return data;
    } catch (error) {
      _utils.logger.log(`Error retrieving data: ${JSON.stringify(error)}`);
      return undefined;
    }
  };
  return {
    store,
    retrieve,
    clear: storageRef.current.cleanStorage
  };
};
exports.useEncryptedStorage = useEncryptedStorage;
//# sourceMappingURL=useEncryptedStorage.js.map