"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSocketActions = void 0;
var _react = require("react");
var _Component = require("../context/Storage/Component");
var _types = require("../types");
var _constants = require("../constants");
var _useEncryptedStorage = require("./useEncryptedStorage");
var _services = require("../services");
var _global = require("../global");
var _utils = require("../utils");
const useSocketActions = () => {
  const {
    botId,
    env
  } = _global.Global;
  const api = (0, _services.createService)(env === null || env === void 0 ? void 0 : env.API_URL);
  const {
    store,
    retrieve
  } = (0, _useEncryptedStorage.useEncryptedStorage)();
  const {
    addMessage
  } = (0, _Component.useStorage)();
  const subscribe = (0, _react.useCallback)(async () => {
    const sessionId = await retrieve('sessionId');
    try {
      const {
        data
      } = await api.post('/webchat/subscribe', {
        sessionId,
        botId,
        parameters: JSON.stringify(_global.Global.params)
      });
      const hasToStoreNewSessionId = !sessionId || sessionId !== data.sessionId;
      if (hasToStoreNewSessionId) await store('sessionId', data.sessionId);
    } catch (error) {
      _utils.logger.log(`Error on subscribe: ${JSON.stringify(error)}`);
    }
  }, [botId]);
  const handleSubmitMessage = (0, _react.useCallback)(async _ref => {
    let {
      message,
      type,
      ext
    } = _ref;
    const sessionId = await retrieve('sessionId');
    const isMedia = type !== _types.MessageTypes.TEXT;
    try {
      addMessage({
        from: _types.From.USER,
        message,
        type
      });
      await api.post('/webchat/message', {
        botId,
        message,
        isMedia,
        ext,
        sessionId,
        botChannel: _constants.channel,
        isPreview: false
      });
    } catch (error) {
      _utils.logger.log(`Error sending message ${JSON.stringify(error)}`);
    }
  }, [botId]);
  const sendAction = (0, _react.useCallback)(async action => {
    try {
      const sessionId = await retrieve('sessionId');
      await api.post('/webchat/action', {
        botId,
        action,
        sessionId
      });
    } catch (error) {
      _utils.logger.log(`Error when sending action: ${JSON.stringify(error)}`);
    }
  }, [botId]);
  return {
    subscribe,
    handleSubmitMessage,
    sendAction
  };
};
exports.useSocketActions = useSocketActions;
//# sourceMappingURL=useSocketActions.js.map