"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ChatbotWebSocket = void 0;
var _utils = require("../utils");
class ChatbotWebSocket {
  ws = null;
  onMessageCallback = null;
  onOpenCallback = null;
  constructor(url) {
    this.url = url;
  }
  onMessage(callback) {
    this.onMessageCallback = callback;
  }
  onOpen(callback) {
    this.onOpenCallback = callback;
  }
  connect() {
    this.ws = new WebSocket(this.url);
    this.ws.onopen = () => {
      if (this.onOpenCallback) this.onOpenCallback();
    };
    this.ws.onclose = event => {
      _utils.logger.log(`Socket is closed. Reconnect will be attempted in 1 second. ${event.reason}`);
      setTimeout(() => {
        this.connect();
      }, 1000);
    };
    this.ws.onerror = err => {
      var _this$ws;
      _utils.logger.log(`Socket encountered error: ${JSON.stringify(err)}`);
      (_this$ws = this.ws) === null || _this$ws === void 0 ? void 0 : _this$ws.close();
    };
    this.ws.onmessage = event => {
      const socketAction = JSON.parse(event.data);
      if (socketAction.action === 'message' && this.onMessageCallback) {
        this.onMessageCallback(socketAction.data);
      }
    };
  }
  disconnect() {
    if (this.ws) {
      this.ws.close();
      this.ws = null;
    }
  }
  sendMessage(action) {
    if (this.ws) {
      this.ws.send(JSON.stringify(action));
    }
  }
}
exports.ChatbotWebSocket = ChatbotWebSocket;
//# sourceMappingURL=ChatbotWebsocket.js.map