import React, { useState, useCallback } from 'react';
import { TextInput, View, TouchableOpacity, Image } from 'react-native';
import { MessageTypes, From } from '../../../../types';
import FilePicker from './components/FilePicker';
import { useSocketActions } from '../../../../hooks';
import { toBase64 } from './utils/toBase64';
import sendIcon from '../../../../assets/send_icon.png';
import { styles } from './styles';
const ONE_THOUSAND = 1000;
function Input() {
  const {
    handleSubmitMessage
  } = useSocketActions();
  const [userText, setUserText] = useState('');
  const getMessageType = type => {
    switch (type) {
      case 'application':
      case 'msword':
      case 'text':
        return MessageTypes.DOCUMENT;
      case 'video':
        return MessageTypes.VIDEO;
      case 'image':
        return MessageTypes.IMAGE;
      default:
        return MessageTypes.IMAGE;
    }
  };
  const onAttach = useCallback(async files => {
    files.forEach(async file => {
      var _file$type;
      const [type, ext] = file === null || file === void 0 ? void 0 : (_file$type = file.type) === null || _file$type === void 0 ? void 0 : _file$type.split('/');
      const messageType = getMessageType(type);
      const base64String = await toBase64(file === null || file === void 0 ? void 0 : file.uri);
      const msg = {
        ext,
        from: From.USER,
        isMedia: true,
        type: messageType,
        message: `data:${file === null || file === void 0 ? void 0 : file.type};base64,${base64String}`,
        localFileUri: file === null || file === void 0 ? void 0 : file.uri
      };
      if ([MessageTypes.DOCUMENT, MessageTypes.VIDEO].includes(messageType)) {
        msg.document = {
          fileUrl: file === null || file === void 0 ? void 0 : file.uri,
          size: file === null || file === void 0 ? void 0 : file.size,
          title: file === null || file === void 0 ? void 0 : file.name
        };
      }
      handleSubmitMessage(msg);
    });
  }, []);
  const onSend = () => {
    if (!userText) return;else {
      const msg = {
        type: MessageTypes.TEXT,
        message: userText,
        from: From.USER
      };
      handleSubmitMessage(msg);
      setUserText('');
    }
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(TextInput, {
    placeholder: "Digite algo ...",
    placeholderTextColor: "#979AA5",
    onChangeText: setUserText,
    style: styles.input,
    value: userText,
    maxLength: ONE_THOUSAND
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.icons
  }, /*#__PURE__*/React.createElement(FilePicker, {
    onSelect: onAttach
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onSend
  }, /*#__PURE__*/React.createElement(Image, {
    source: sendIcon,
    style: styles.sendIcon
  }))));
}
export default Input;
//# sourceMappingURL=index.js.map