import React, { useMemo, useState } from 'react';
import { Image, Text, TouchableOpacity, ActivityIndicator, StyleSheet } from 'react-native';
import { From } from '../../../../../../types/message';
import { getFileNameFromAttachment } from '../../../../../../utils/getFilenameFromAttachment';
import RNFS from 'react-native-fs';
import attachIcon from '../../../../../../assets/attach_icon.png';
import { useChatConfigurations } from '../../../../../../context/ChatConfigurations';
const DocumentComponent = msg => {
  const {
    botConfigs
  } = useChatConfigurations();
  const [isDownloading, setIsDownloading] = useState(false);
  const fileName = useMemo(() => getFileNameFromAttachment(msg.document), [msg.document]);
  const downloadDocumentToDevice = async () => {
    setIsDownloading(true);
    try {
      var _msg$document;
      const destination = `${RNFS.DownloadDirectoryPath}/${fileName}`;
      const job = RNFS.downloadFile({
        fromUrl: (_msg$document = msg.document) === null || _msg$document === void 0 ? void 0 : _msg$document.fileUrl,
        toFile: destination
      });
      await job.promise;
    } catch (error) {
      throw error;
    } finally {
      setIsDownloading(false);
    }
  };
  const onDocumentPress = () => {
    downloadDocumentToDevice();
  };
  const styles = StyleSheet.create({
    bot: {
      color: botConfigs.colors.secondaryText
    },
    user: {
      color: botConfigs.colors.mainText
    },
    container: {
      flexDirection: 'row'
    },
    text: {
      marginLeft: 8
    }
  });
  const textColor = msg.from === From.BOT ? styles.bot : styles.user;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onDocumentPress,
    style: styles.container
  }, isDownloading ? /*#__PURE__*/React.createElement(ActivityIndicator, null) : /*#__PURE__*/React.createElement(Image, {
    source: attachIcon
  }), /*#__PURE__*/React.createElement(Text, {
    style: [styles.text, textColor]
  }, fileName));
};
export default DocumentComponent;
//# sourceMappingURL=index.js.map