import React, { createContext, useContext, useState, useCallback } from 'react';
import { createService } from '../services';
import { logger } from '../utils';
import { Global } from '../global';
const defaultBotConfig = {
  title: 'Bot title',
  botFab: '',
  colors: {
    main: '#254EDB',
    mainText: '#FFFFFF',
    secondary: '#DADCE3',
    secondaryText: '#5A5D68'
  }
};
const ChatConfigurationsContext = /*#__PURE__*/createContext({
  isChatOpen: false,
  toggleIsChatOpen: () => {},
  setBotConfigs: () => {},
  botConfigs: defaultBotConfig,
  fetchBotAndUpdateConfigs: async () => {}
});
const IsChatOpenProvider = _ref => {
  let {
    children,
    appearance,
    apiUrl
  } = _ref;
  const getBotService = createService(apiUrl);
  const [isChatOpen, setIsChatOpen] = useState(false);
  const [configs, setConfigs] = useState(defaultBotConfig);
  const toggleIsChatOpen = useCallback(() => {
    setIsChatOpen(oldValue => !oldValue);
  }, [isChatOpen, setIsChatOpen]);
  const setBotConfigs = useCallback(cfg => setConfigs(cfg), []);
  const fetchBotAndUpdateConfigs = useCallback(async () => {
    try {
      var _data$channels, _webchatChannel$setti, _webchatChannel$setti2, _webchatChannel$setti3, _webchatChannel$setti4, _webchatChannel$setti5;
      const {
        data
      } = await getBotService.get(Global.botId);
      const [webchatChannel] = data === null || data === void 0 ? void 0 : (_data$channels = data.channels) === null || _data$channels === void 0 ? void 0 : _data$channels.filter(ch => {
        return ch.channelId === 'WebChat';
      });
      const botConfigs = {
        title: data === null || data === void 0 ? void 0 : data.title,
        botFab: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti = webchatChannel.settings) === null || _webchatChannel$setti === void 0 ? void 0 : _webchatChannel$setti.botFab),
        colors: {
          main: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti2 = webchatChannel.settings) === null || _webchatChannel$setti2 === void 0 ? void 0 : _webchatChannel$setti2.mainColor),
          secondary: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti3 = webchatChannel.settings) === null || _webchatChannel$setti3 === void 0 ? void 0 : _webchatChannel$setti3.secondaryColor),
          mainText: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti4 = webchatChannel.settings) === null || _webchatChannel$setti4 === void 0 ? void 0 : _webchatChannel$setti4.mainTextColor),
          secondaryText: String(webchatChannel === null || webchatChannel === void 0 ? void 0 : (_webchatChannel$setti5 = webchatChannel.settings) === null || _webchatChannel$setti5 === void 0 ? void 0 : _webchatChannel$setti5.secondaryTextColor)
        }
      };
      setBotConfigs({
        ...botConfigs,
        ...appearance,
        colors: {
          ...botConfigs.colors,
          ...(appearance === null || appearance === void 0 ? void 0 : appearance.colors)
        }
      });
    } catch (error) {
      logger.log(`Error getting bot styles: ${JSON.stringify(error)}`);
      setBotConfigs({
        ...defaultBotConfig,
        ...appearance,
        colors: {
          ...defaultBotConfig.colors,
          ...(appearance === null || appearance === void 0 ? void 0 : appearance.colors)
        }
      });
    }
  }, []);
  const chatConfigurationsState = {
    isChatOpen,
    toggleIsChatOpen,
    setBotConfigs,
    botConfigs: configs,
    fetchBotAndUpdateConfigs
  };
  return /*#__PURE__*/React.createElement(ChatConfigurationsContext.Provider, {
    value: chatConfigurationsState
  }, children);
};
export default IsChatOpenProvider;
export const useChatConfigurations = () => useContext(ChatConfigurationsContext);
//# sourceMappingURL=ChatConfigurations.js.map