import React, { useContext, useState, useEffect } from 'react';
import { StorageContext, StorageContextProvider } from './Context';
import { MessageTypes } from '../../types';
import { useEncryptedStorage } from '../../hooks/useEncryptedStorage';
import { useDebounce } from '../../hooks/useDebounce';
import { getHourAndMinutes } from '../../utils';
const TWO_SECONDS = 2000;
const StorageContextComponent = _ref => {
  let {
    children
  } = _ref;
  const {
    retrieve,
    store
  } = useEncryptedStorage();
  const [messages, setMessages] = useState([]);
  const debouncedMessages = useDebounce(messages, TWO_SECONDS);
  useEffect(() => {
    const getStoredData = async () => {
      const storedMessages = await retrieve('messages');
      if (storedMessages) setMessages(JSON.parse(storedMessages));
    };
    getStoredData();
  }, []);
  useEffect(() => {
    const storeMessages = async () => {
      if (debouncedMessages.length) {
        store('messages', debouncedMessages);
      }
    };
    storeMessages();
  }, [debouncedMessages]);
  const addMessage = newMessage => {
    setMessages(prevState => {
      var _prevState$filter;
      const newMessages = [...((prevState === null || prevState === void 0 ? void 0 : (_prevState$filter = prevState.filter) === null || _prevState$filter === void 0 ? void 0 : _prevState$filter.call(prevState, m => m.type !== MessageTypes.TYPING)) ?? []), {
        ...newMessage,
        hour: getHourAndMinutes()
      }];
      return newMessages;
    });
  };
  const resetMessages = () => setMessages([]);
  return /*#__PURE__*/React.createElement(StorageContextProvider, {
    value: {
      messages,
      addMessage,
      resetMessages
    }
  }, children);
};
export default StorageContextComponent;
export const useStorage = () => useContext(StorageContext);
//# sourceMappingURL=Component.js.map