import { useRef } from 'react';
import { EncryptedStorageProvider } from '../providers';
import { logger } from '../utils';
export const useEncryptedStorage = () => {
  const storageRef = useRef(new EncryptedStorageProvider());
  const store = async (key, data) => {
    try {
      await storageRef.current.storeData(key, data);
    } catch (error) {
      logger.log(`Error storing data: ${JSON.stringify(error)}`);
    }
  };
  const retrieve = async key => {
    try {
      const data = await storageRef.current.retrieveData(key);
      return data;
    } catch (error) {
      logger.log(`Error retrieving data: ${JSON.stringify(error)}`);
      return undefined;
    }
  };
  return {
    store,
    retrieve,
    clear: storageRef.current.cleanStorage
  };
};
//# sourceMappingURL=useEncryptedStorage.js.map