import { useRef, useEffect, useState } from 'react';
import { ChatbotWebSocket } from '../providers';
import { From } from '../types';
import { useStorage } from '../context/Storage/Component';
import { useSocketActions } from './useSocketActions';
import { sendNotification } from '../utils';
export const useSocket = wsUrl => {
  const isFirstRender = useRef(true);
  const wsRef = useRef(null);
  const [waitingToReconnect, setWaitingToReconnect] = useState(false);
  const {
    subscribe
  } = useSocketActions();
  const {
    addMessage
  } = useStorage();
  const onOpenCallback = async () => {
    await subscribe();
  };
  const onMessageCallback = msg => {
    sendNotification(msg);
    addMessage({
      ...msg,
      from: From.BOT
    });
  };
  const disconnect = () => {
    var _wsRef$current;
    (_wsRef$current = wsRef.current) === null || _wsRef$current === void 0 ? void 0 : _wsRef$current.disconnect();
    setWaitingToReconnect(true);
  };
  useEffect(() => {
    if (isFirstRender.current) {
      isFirstRender.current = false;
      return;
    }
    if (!wsRef.current) {
      wsRef.current = new ChatbotWebSocket(wsUrl);
      wsRef.current.onMessage(onMessageCallback);
      wsRef.current.onOpen(onOpenCallback);
      wsRef.current.connect();
    }
    return () => {
      var _wsRef$current2;
      (_wsRef$current2 = wsRef.current) === null || _wsRef$current2 === void 0 ? void 0 : _wsRef$current2.disconnect();
    };
  }, [isFirstRender.current, waitingToReconnect]);
  return {
    disconnect
  };
};
//# sourceMappingURL=useSocket.js.map