import { useCallback } from 'react';
import { useStorage } from '../context/Storage/Component';
import { MessageTypes, From } from '../types';
import { channel } from '../constants';
import { useEncryptedStorage } from './useEncryptedStorage';
import { createService } from '../services';
import { Global } from '../global';
import { logger } from '../utils';
export const useSocketActions = () => {
  const {
    botId,
    env
  } = Global;
  const api = createService(env === null || env === void 0 ? void 0 : env.API_URL);
  const {
    store,
    retrieve
  } = useEncryptedStorage();
  const {
    addMessage
  } = useStorage();
  const subscribe = useCallback(async () => {
    const sessionId = await retrieve('sessionId');
    try {
      const {
        data
      } = await api.post('/webchat/subscribe', {
        sessionId,
        botId,
        parameters: JSON.stringify(Global.params)
      });
      const hasToStoreNewSessionId = !sessionId || sessionId !== data.sessionId;
      if (hasToStoreNewSessionId) await store('sessionId', data.sessionId);
    } catch (error) {
      logger.log(`Error on subscribe: ${JSON.stringify(error)}`);
    }
  }, [botId]);
  const handleSubmitMessage = useCallback(async _ref => {
    let {
      message,
      type,
      ext
    } = _ref;
    const sessionId = await retrieve('sessionId');
    const isMedia = type !== MessageTypes.TEXT;
    try {
      addMessage({
        from: From.USER,
        message,
        type
      });
      await api.post('/webchat/message', {
        botId,
        message,
        isMedia,
        ext,
        sessionId,
        botChannel: channel,
        isPreview: false
      });
    } catch (error) {
      logger.log(`Error sending message ${JSON.stringify(error)}`);
    }
  }, [botId]);
  const sendAction = useCallback(async action => {
    try {
      const sessionId = await retrieve('sessionId');
      await api.post('/webchat/action', {
        botId,
        action,
        sessionId
      });
    } catch (error) {
      logger.log(`Error when sending action: ${JSON.stringify(error)}`);
    }
  }, [botId]);
  return {
    subscribe,
    handleSubmitMessage,
    sendAction
  };
};
//# sourceMappingURL=useSocketActions.js.map